@@ -2,7 +2,7 @@
 #
 #       config.py
 #
-#       Copyright 2009-2015 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2016 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #       MA 02110-1301, USA.
 
 import os, sys, ConfigParser, gtk, pango, locale, subprocess, base64, webbrowser
-import cons, support, codeboxes, pgsc_spellcheck
+import cons, support, exports, codeboxes, pgsc_spellcheck
 if cons.HAS_APPINDICATOR: import appindicator
 
 ICONS_SIZE = {1: gtk.ICON_SIZE_MENU, 2: gtk.ICON_SIZE_SMALL_TOOLBAR, 3: gtk.ICON_SIZE_LARGE_TOOLBAR,
@@ -33,7 +33,7 @@ COLOR_PALETTE_DEFAULT = ["#000000", "#ffffff", "#7f7f7f", "#ff0000", "#a020f0",
                          "#0000ff", "#add8e6", "#00ff00", "#ffff00", "#ffa500",
                          "#e6e6fa", "#a52a2a", "#8b6914", "#1e90ff", "#ffc0cb",
                          "#90ee90", "#1a1a1a", "#4d4d4d", "#bfbfbf", "#e5e5e5"]
-SPECIAL_CHARS_DEFAULT = "“”„•◇▪▸☐☑☒…‰€©®™°↓↑→←↔↵⇓⇑⇒⇐⇔»«▼▲►◄≤≥≠±¹²³½¼⅛×÷∞ø∑√∫ΔδΠπΣΦΩωαβγεηλμ☺☻☼♥♀♂♪♫"
+SPECIAL_CHARS_DEFAULT = "“”„•◇▪▸☐☑☒★…‰€©®™°↓↑→←↔↵⇓⇑⇒⇐⇔»«▼▲►◄≤≥≠≈±¹²³½¼⅛×÷∞ø∑√∫ΔδΠπΣΦΩωαβγεηλμ☺☻☼♥♣♦✔♀♂♪♫✝"
 SELWORD_CHARS_DEFAULT = ".-@"
 TIMESTAMP_FORMAT_DEFAULT = "%Y/%m/%d - %H:%M"
 TOOLBAR_VEC_DEFAULT = ["TreeAddNode", "TreeAddSubNode", cons.TAG_SEPARATOR, "GoBack", "GoForward", cons.TAG_SEPARATOR, cons.CHAR_STAR, "Save", "Export2PDF", cons.TAG_SEPARATOR, "FindInNodes", cons.TAG_SEPARATOR, "BulletedList", "NumberedList", "ToDoList", cons.TAG_SEPARATOR, "HandleImage", "HandleTable", "HandleCodeBox", "EmbFileInsert", "HandleLink", "HandleAnchor", cons.TAG_SEPARATOR, "RemoveFormatting", "ColorForeground", "ColorBackground", "Bold", "Italic", "Underline", "Strikethrough", "H1", "H2", "H3", "Small", "Superscript", "Subscript", "Monospace"]
@@ -88,7 +88,10 @@ def config_file_load(inst):
     """Load the Preferences from Config File"""
     if os.path.isfile(cons.CONFIG_PATH):
         config = ConfigParser.RawConfigParser()
-        config.read(cons.CONFIG_PATH)
+        try:
+            config.read(cons.CONFIG_PATH)
+        except ConfigParser.MissingSectionHeaderError:
+            print "? ConfigParser.MissingSectionHeaderError"
 
         section = "state"
         inst.file_dir = unicode(config.get(section, "file_dir"), cons.STR_UTF8, cons.STR_IGNORE) if config.has_option(section, "file_dir") else ""
@@ -148,7 +151,7 @@ def config_file_load(inst):
         section = "editor"
         inst.syntax_highlighting = config.get(section, "syntax_highlighting") if config.has_option(section, "syntax_highlighting") else cons.RICH_TEXT_ID
         inst.auto_syn_highl = config.get(section, "auto_syn_highl") if config.has_option(section, "auto_syn_highl") else "sh"
-        inst.style_scheme = config.get(section, "style_scheme") if config.has_option(section, "style_scheme") else cons.STYLE_SCHEME_DEFAULT
+        inst.style_scheme = config.get(section, "style_scheme") if config.has_option(section, "style_scheme") else cons.STYLE_SCHEME_DARK
         inst.enable_spell_check = config.getboolean(section, "enable_spell_check") if config.has_option(section, "enable_spell_check") else False
         inst.spell_check_lang = config.get(section, "spell_check_lang") if config.has_option(section, "spell_check_lang") else SPELL_CHECK_LANG_DEFAULT
         inst.show_line_numbers = config.getboolean(section, "show_line_numbers") if config.has_option(section, "show_line_numbers") else False
@@ -160,8 +163,9 @@ def config_file_load(inst):
         inst.wrapping_indent = config.getint(section, "wrapping_indent") if config.has_option(section, "wrapping_indent") else -14
         inst.auto_indent = config.getboolean(section, "auto_indent") if config.has_option(section, "auto_indent") else True
         inst.rt_show_white_spaces = config.getboolean(section, "rt_show_white_spaces") if config.has_option(section, "rt_show_white_spaces") else False
-        inst.show_white_spaces = config.getboolean(section, "show_white_spaces") if config.has_option(section, "show_white_spaces") else True
-        inst.highl_curr_line = config.getboolean(section, "highl_curr_line") if config.has_option(section, "highl_curr_line") else True
+        inst.pt_show_white_spaces = config.getboolean(section, "pt_show_white_spaces") if config.has_option(section, "pt_show_white_spaces") else True
+        inst.rt_highl_curr_line = config.getboolean(section, "rt_highl_curr_line") if config.has_option(section, "rt_highl_curr_line") else True
+        inst.pt_highl_curr_line = config.getboolean(section, "pt_highl_curr_line") if config.has_option(section, "pt_highl_curr_line") else True
         inst.h_rule = config.get(section, "h_rule") if config.has_option(section, "h_rule") else HORIZONTAL_RULE
         inst.special_chars = unicode(config.get(section, "special_chars") if config.has_option(section, "special_chars") else SPECIAL_CHARS_DEFAULT, cons.STR_UTF8, cons.STR_IGNORE)
         inst.selword_chars = unicode(config.get(section, "selword_chars") if config.has_option(section, "selword_chars") else SELWORD_CHARS_DEFAULT, cons.STR_UTF8, cons.STR_IGNORE)
@@ -241,7 +245,7 @@ def config_file_load(inst):
         inst.curr_colors = {'f':None, 'b':None}
         inst.syntax_highlighting = cons.RICH_TEXT_ID
         inst.auto_syn_highl = "sh"
-        inst.style_scheme = cons.STYLE_SCHEME_DEFAULT
+        inst.style_scheme = cons.STYLE_SCHEME_DARK
         inst.tree_font = "Sans 8" # default tree font
         inst.text_font = "Sans 9" # default text font
         inst.code_font = "Monospace 9" # default code font
@@ -310,8 +314,9 @@ def config_file_load(inst):
         inst.tree_right_side = False
         inst.nodes_bookm_exp = True
         inst.rt_show_white_spaces = False
-        inst.show_white_spaces = True
-        inst.highl_curr_line = True
+        inst.pt_show_white_spaces = True
+        inst.rt_highl_curr_line = True
+        inst.pt_highl_curr_line = True
         inst.hpaned_pos = 170
         inst.show_node_name_label = True
         inst.nodes_icons = "c"
@@ -423,8 +428,9 @@ def config_file_save(inst):
     config.set(section, "wrapping_indent", inst.wrapping_indent)
     config.set(section, "auto_indent", inst.auto_indent)
     config.set(section, "rt_show_white_spaces", inst.rt_show_white_spaces)
-    config.set(section, "show_white_spaces", inst.show_white_spaces)
-    config.set(section, "highl_curr_line", inst.highl_curr_line)
+    config.set(section, "pt_show_white_spaces", inst.pt_show_white_spaces)
+    config.set(section, "rt_highl_curr_line", inst.rt_highl_curr_line)
+    config.set(section, "pt_highl_curr_line", inst.pt_highl_curr_line)
     config.set(section, "h_rule", inst.h_rule)
     config.set(section, "special_chars", inst.special_chars)
     config.set(section, "selword_chars", inst.selword_chars)
@@ -771,6 +777,8 @@ def preferences_tab_rich_text_nodes(dad, vbox_text_nodes, pref_dialog):
     hbox_misc_text.set_spacing(4)
     checkbutton_rt_show_white_spaces = gtk.CheckButton(_("Show White Spaces"))
     checkbutton_rt_show_white_spaces.set_active(dad.rt_show_white_spaces)
+    checkbutton_rt_highl_curr_line = gtk.CheckButton(_("Highlight Current Line"))
+    checkbutton_rt_highl_curr_line.set_active(dad.rt_highl_curr_line)
     checkbutton_codebox_auto_resize = gtk.CheckButton(_("Expand CodeBoxes Automatically"))
     checkbutton_codebox_auto_resize.set_active(dad.codebox_auto_resize)
     hbox_embfile_size = gtk.HBox()
@@ -790,6 +798,7 @@ def preferences_tab_rich_text_nodes(dad, vbox_text_nodes, pref_dialog):
 
     vbox_misc_text = gtk.VBox()
     vbox_misc_text.pack_start(checkbutton_rt_show_white_spaces, expand=False)
+    vbox_misc_text.pack_start(checkbutton_rt_highl_curr_line, expand=False)
     vbox_misc_text.pack_start(checkbutton_codebox_auto_resize, expand=False)
     vbox_misc_text.pack_start(hbox_embfile_size, expand=False)
     vbox_misc_text.pack_start(hbox_misc_text, expand=False)
@@ -818,14 +827,18 @@ def preferences_tab_rich_text_nodes(dad, vbox_text_nodes, pref_dialog):
         if new_lang_code != dad.spell_check_lang: dad.spell_check_set_new_lang(new_lang_code)
     combobox_spell_check_lang.connect('changed', on_combobox_spell_check_lang_changed)
     def on_colorbutton_text_fg_color_set(colorbutton):
-        dad.rt_def_fg = "#" + dad.html_handler.rgb_to_24(colorbutton.get_color().to_string()[1:])
+        dad.rt_def_fg = "#" + exports.rgb_any_to_24(colorbutton.get_color().to_string()[1:])
         if dad.curr_tree_iter and dad.syntax_highlighting == cons.RICH_TEXT_ID:
             dad.widget_set_colors(dad.sourceview, dad.rt_def_fg, dad.rt_def_bg, False)
             support.rich_text_node_modify_codeboxes_color(dad.curr_buffer.get_start_iter(), dad)
     colorbutton_text_fg.connect('color-set', on_colorbutton_text_fg_color_set)
     def on_colorbutton_text_bg_color_set(colorbutton):
-        dad.rt_def_bg = "#" + dad.html_handler.rgb_to_24(colorbutton.get_color().to_string()[1:])
+        dad.rt_def_bg = "#" + exports.rgb_any_to_24(colorbutton.get_color().to_string()[1:])
         if dad.curr_tree_iter and dad.syntax_highlighting == cons.RICH_TEXT_ID:
+            if dad.rt_highl_curr_line:
+                dad.set_sourcebuffer_with_style_scheme()
+                dad.sourceview.set_buffer(dad.curr_buffer)
+                dad.objects_buffer_refresh()
             dad.widget_set_colors(dad.sourceview, dad.rt_def_fg, dad.rt_def_bg, False)
             support.rich_text_node_modify_codeboxes_color(dad.curr_buffer.get_start_iter(), dad)
     colorbutton_text_bg.connect('color-set', on_colorbutton_text_bg_color_set)
@@ -857,6 +870,11 @@ def preferences_tab_rich_text_nodes(dad, vbox_text_nodes, pref_dialog):
         if dad.syntax_highlighting == cons.RICH_TEXT_ID:
             dad.sourceview.set_draw_spaces(codeboxes.DRAW_SPACES_FLAGS if dad.rt_show_white_spaces else 0)
     checkbutton_rt_show_white_spaces.connect('toggled', on_checkbutton_rt_show_white_spaces_toggled)
+    def on_checkbutton_rt_highl_curr_line_toggled(checkbutton):
+        dad.rt_highl_curr_line = checkbutton.get_active()
+        if dad.syntax_highlighting == cons.RICH_TEXT_ID:
+            dad.sourceview.set_highlight_current_line(dad.rt_highl_curr_line)
+    checkbutton_rt_highl_curr_line.connect('toggled', on_checkbutton_rt_highl_curr_line_toggled)
     def on_checkbutton_codebox_auto_resize_toggled(checkbutton):
         dad.codebox_auto_resize = checkbutton.get_active()
     checkbutton_codebox_auto_resize.connect('toggled', on_checkbutton_codebox_auto_resize_toggled)
@@ -889,14 +907,14 @@ def preferences_tab_plain_text_n_code_nodes(dad, vbox_code_nodes, pref_dialog):
     combobox_style_scheme.set_active_iter(dad.get_combobox_iter_from_value(dad.style_scheme_liststore, 0, dad.style_scheme))
     hbox_style_scheme.pack_start(label_style_scheme, expand=False)
     hbox_style_scheme.pack_start(combobox_style_scheme)
-    checkbutton_show_white_spaces = gtk.CheckButton(_("Show White Spaces"))
-    checkbutton_show_white_spaces.set_active(dad.show_white_spaces)
-    checkbutton_highlight_current_line = gtk.CheckButton(_("Highlight Current Line"))
-    checkbutton_highlight_current_line.set_active(dad.highl_curr_line)
+    checkbutton_pt_show_white_spaces = gtk.CheckButton(_("Show White Spaces"))
+    checkbutton_pt_show_white_spaces.set_active(dad.pt_show_white_spaces)
+    checkbutton_pt_highl_curr_line = gtk.CheckButton(_("Highlight Current Line"))
+    checkbutton_pt_highl_curr_line.set_active(dad.pt_highl_curr_line)
 
     vbox_syntax.pack_start(hbox_style_scheme, expand=False)
-    vbox_syntax.pack_start(checkbutton_show_white_spaces, expand=False)
-    vbox_syntax.pack_start(checkbutton_highlight_current_line, expand=False)
+    vbox_syntax.pack_start(checkbutton_pt_show_white_spaces, expand=False)
+    vbox_syntax.pack_start(checkbutton_pt_highl_curr_line, expand=False)
 
     frame_syntax = gtk.Frame(label="<b>"+_("Code Nodes")+"</b>")
     frame_syntax.get_label_widget().set_use_markup(True)
@@ -914,16 +932,16 @@ def preferences_tab_plain_text_n_code_nodes(dad, vbox_code_nodes, pref_dialog):
             dad.style_scheme = new_style
             support.dialog_info_after_restart(pref_dialog)
     combobox_style_scheme.connect('changed', on_combobox_style_scheme_changed)
-    def on_checkbutton_show_white_spaces_toggled(checkbutton):
-        dad.show_white_spaces = checkbutton.get_active()
+    def on_checkbutton_pt_show_white_spaces_toggled(checkbutton):
+        dad.pt_show_white_spaces = checkbutton.get_active()
         if dad.syntax_highlighting != cons.RICH_TEXT_ID:
-            dad.sourceview.set_draw_spaces(codeboxes.DRAW_SPACES_FLAGS if dad.show_white_spaces else 0)
-    checkbutton_show_white_spaces.connect('toggled', on_checkbutton_show_white_spaces_toggled)
-    def on_checkbutton_highlight_current_line_toggled(checkbutton):
-        dad.highl_curr_line = checkbutton.get_active()
+            dad.sourceview.set_draw_spaces(codeboxes.DRAW_SPACES_FLAGS if dad.pt_show_white_spaces else 0)
+    checkbutton_pt_show_white_spaces.connect('toggled', on_checkbutton_pt_show_white_spaces_toggled)
+    def on_checkbutton_pt_highl_curr_line_toggled(checkbutton):
+        dad.pt_highl_curr_line = checkbutton.get_active()
         if dad.syntax_highlighting != cons.RICH_TEXT_ID:
-            dad.sourceview.set_highlight_current_line(dad.highl_curr_line)
-    checkbutton_highlight_current_line.connect('toggled', on_checkbutton_highlight_current_line_toggled)
+            dad.sourceview.set_highlight_current_line(dad.pt_highl_curr_line)
+    checkbutton_pt_highl_curr_line.connect('toggled', on_checkbutton_pt_highl_curr_line_toggled)
 
 def preferences_tab_tree(dad, vbox_tree, pref_dialog):
     """Preferences Dialog, Tree Tab"""
@@ -1044,12 +1062,12 @@ def preferences_tab_tree(dad, vbox_tree, pref_dialog):
     vbox_tree.pack_start(frame_nodes_startup, expand=False)
     vbox_tree.pack_start(frame_misc_tree, expand=False)
     def on_colorbutton_tree_fg_color_set(colorbutton):
-        dad.tt_def_fg = "#" + dad.html_handler.rgb_to_24(colorbutton.get_color().to_string()[1:])
+        dad.tt_def_fg = "#" + exports.rgb_any_to_24(colorbutton.get_color().to_string()[1:])
         dad.widget_set_colors(dad.treeview, dad.tt_def_fg, dad.tt_def_bg, False)
         if dad.curr_tree_iter: dad.update_node_name_header()
     colorbutton_tree_fg.connect('color-set', on_colorbutton_tree_fg_color_set)
     def on_colorbutton_tree_bg_color_set(colorbutton):
-        dad.tt_def_bg = "#" + dad.html_handler.rgb_to_24(colorbutton.get_color().to_string()[1:])
+        dad.tt_def_bg = "#" + exports.rgb_any_to_24(colorbutton.get_color().to_string()[1:])
         dad.widget_set_colors(dad.treeview, dad.tt_def_fg, dad.tt_def_bg, False)
         if dad.curr_tree_iter: dad.update_node_name_header()
     colorbutton_tree_bg.connect('color-set', on_colorbutton_tree_bg_color_set)
@@ -1170,13 +1188,13 @@ def preferences_tab_fonts(dad, vbox_fonts, pref_dialog):
     vbox_fonts.pack_start(frame_fonts, expand=False)
     def on_fontbutton_text_font_set(picker):
         dad.text_font = picker.get_font_name()
-        if dad.curr_tree_iter and dad.syntax_highlighting == cons.RICH_TEXT_ID:
+        if dad.curr_tree_iter and dad.syntax_highlighting in [cons.RICH_TEXT_ID, cons.PLAIN_TEXT_ID]:
             dad.sourceview.modify_font(pango.FontDescription(dad.text_font))
     fontbutton_text.connect('font-set', on_fontbutton_text_font_set)
     def on_fontbutton_code_font_set(picker):
         dad.code_font = picker.get_font_name()
         if not dad.curr_tree_iter: return
-        if dad.syntax_highlighting != cons.RICH_TEXT_ID:
+        if dad.syntax_highlighting not in [cons.RICH_TEXT_ID, cons.PLAIN_TEXT_ID]:
             dad.sourceview.modify_font(pango.FontDescription(dad.code_font))
         else:
             support.rich_text_node_modify_codeboxes_font(dad.curr_buffer.get_start_iter(), dad.code_font)
