@@ -2,7 +2,7 @@
 #
 #       cons.py
 #
-#       Copyright 2009-2015 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2016 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -22,35 +22,35 @@
 import os, sys
 
 
-VERSION = "0.36.2"
+VERSION = "0.36.5"
 APP_NAME = "cherrytree"
 NEWER_VERSION_URL = "http://www.giuspen.com/software/version_cherrytree"
 if sys.platform.startswith("win"):
     IS_WIN_OS = True
     SZA_PATH = '"'+os.path.join(SHARE_PATH, "7za.exe")+'"'
-    if SHARE_PATH:
-        EXE_DIR = SHARE_PATH
-        os.chdir(EXE_DIR)
-    else: EXE_DIR = os.getcwd()
     TMP_FOLDER = os.path.join(os.environ['TEMP'], 'ct_tmp/')
-    GLADE_PATH = os.path.join(EXE_DIR, 'glade/')
-    SPECS_PATH = os.path.join(EXE_DIR, 'language-specs/')
-    LOCALE_PATH = os.path.join(EXE_DIR, 'locale/')
-    if not os.path.isfile(os.path.join(EXE_DIR, 'config.cfg')):
+    GLADE_PATH = os.path.join(SHARE_PATH, 'glade/')
+    SPECS_PATH = os.path.join(SHARE_PATH, 'language-specs/')
+    LOCALE_PATH = os.path.join(SHARE_PATH, 'locale/')
+    if not os.path.isfile(os.path.join(SHARE_PATH, 'config.cfg')):
         CONFIG_DIR = os.path.join(os.environ['APPDATA'], APP_NAME)
-    else: CONFIG_DIR = EXE_DIR
+    else:
+        CONFIG_DIR = SHARE_PATH
 else:
     IS_WIN_OS = False
     SZA_PATH = "7za"
-    CONFIG_DIR = os.path.join(os.path.expanduser('~'), '.config/cherrytree')
     TMP_FOLDER = '/tmp/ct_tmp/'
-    if not SHARE_PATH:
-        GLADE_PATH = os.path.join(os.getcwd(), "glade/")
-        SPECS_PATH = os.path.join(os.getcwd(), 'language-specs/')
-        LOCALE_PATH = os.path.join(os.getcwd(), 'locale/')
+    MODULES_PATH = os.path.dirname(os.path.realpath(__file__))
+    CONFIG_DIR = os.path.join(os.path.expanduser('~'), '.config', 'cherrytree')
+    if SHARE_PATH == os.path.dirname(MODULES_PATH):
+        GLADE_PATH = os.path.join(SHARE_PATH, "glade/")
+        SPECS_PATH = os.path.join(SHARE_PATH, 'language-specs/')
+        LOCALE_PATH = os.path.join(SHARE_PATH, 'locale/')
+        if os.path.isfile(os.path.join(SHARE_PATH, 'config.cfg')):
+            CONFIG_DIR = SHARE_PATH
     else:
-        GLADE_PATH = os.path.join(SHARE_PATH, 'cherrytree/glade/')
-        SPECS_PATH = os.path.join(SHARE_PATH, 'cherrytree/language-specs')
+        GLADE_PATH = os.path.join(SHARE_PATH, 'cherrytree', 'glade/')
+        SPECS_PATH = os.path.join(SHARE_PATH, 'cherrytree', 'language-specs')
         LOCALE_PATH = os.path.join(SHARE_PATH, 'locale')
 CONFIG_PATH = os.path.join(CONFIG_DIR, 'config.cfg')
 LANG_PATH = os.path.join(CONFIG_DIR, 'lang')
@@ -63,7 +63,8 @@ except: HAS_APPINDICATOR = False
 XDG_CURRENT_DESKTOP = 'XDG_CURRENT_DESKTOP'
 HAS_SYSTRAY = not (XDG_CURRENT_DESKTOP in os.environ and os.environ[XDG_CURRENT_DESKTOP] == "Unity")
 
-AVAILABLE_LANGS = ['default', 'cs', 'de', 'en', 'es', 'fr', 'hy', 'it', 'ja', 'nl', 'pl', 'pt_BR', 'ru', 'tr', 'uk', 'zh_CN']
+WEB_LINK_STARTERS = ["http://", "https://", "www.", "ftp://"]
+AVAILABLE_LANGS = ['default', 'cs', 'de', 'en', 'es', 'fr', 'hy', 'it', 'ja', 'lt', 'nl', 'pl', 'pt_BR', 'ru', 'sl', 'tr', 'uk', 'zh_CN']
 COLOR_48_LINK_WEBS = "#00004444ffff"
 COLOR_48_LINK_NODE = "#071c838e071c"
 COLOR_48_LINK_FILE = "#8b8b69691414"
@@ -123,7 +124,9 @@ LINK_TYPE_FOLD = "fold"
 LINK_TYPE_NODE = "node"
 RICH_TEXT_ID = "custom-colors"
 PLAIN_TEXT_ID = "plain-text"
-STYLE_SCHEME_DEFAULT = "cobalt"
+STYLE_SCHEME_LIGHT = "classic"
+STYLE_SCHEME_DARK = "cobalt"
+STYLE_SCHEME_GRAY = "oblivion"
 ANCHOR_CHAR = GLADE_PATH + 'anchor.png'
 FILE_CHAR = GLADE_PATH + 'file_icon.png'
 NODES_ICONS = {0:'cherry_red', 1:'cherry_blue', 2:'cherry_orange', 3:'cherry_cyan',
@@ -179,8 +182,11 @@ CHAR_PIPE = "|"
 CHAR_AMPERSAND = "&"
 
 SPECIAL_CHAR_ARROW_RIGHT = "→"
+SPECIAL_CHAR_ARROW_RIGHT2 = "⇒"
 SPECIAL_CHAR_ARROW_LEFT = "←"
+SPECIAL_CHAR_ARROW_LEFT2 = "⇐"
 SPECIAL_CHAR_ARROW_DOUBLE = "↔"
+SPECIAL_CHAR_ARROW_DOUBLE2 = "⇔"
 SPECIAL_CHAR_COPYRIGHT = "©"
 SPECIAL_CHAR_UNREGISTERED_TRADEMARK = "™"
 SPECIAL_CHAR_REGISTERED_TRADEMARK = "®"
