@@ -2,7 +2,7 @@
 #
 #       support.py
 #
-#       Copyright 2009-2015 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2016 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -30,9 +30,12 @@ def auto_decode_str(in_str, from_clipboard=False):
     elif in_str.startswith(("\xFF\xFE", "\xFE\xFF")): # UTF-16 BOMs
         encodings = [cons.STR_UTF16]
     elif from_clipboard:
-        encodings = [cons.STR_UTF8, cons.STR_UTF16]
+        if "html" in in_str or "HTML" in in_str:
+            encodings = [cons.STR_UTF8]
+        else:
+            encodings = [cons.STR_UTF16, cons.STR_UTF8]
     else:
-        encodings = [cons.STR_UTF8, cons.STR_ISO_8859, cons.STR_UTF16, "utf-16le", locale.getdefaultlocale()[1]]
+        encodings = [cons.STR_UTF16, "utf-16le", cons.STR_UTF8, cons.STR_ISO_8859, locale.getdefaultlocale()[1]]
     for enc in encodings:
         try:
             out_str = in_str.decode(enc)
@@ -109,7 +112,8 @@ def on_sourceview_event_after_button_press(dad, text_view, event):
                 dad.link_clicked(tag_name[5:], event.button == 2)
                 return False
         if dad.lists_handler.is_list_todo_beginning(text_iter):
-            dad.lists_handler.todo_list_rotate_status(text_iter, text_buffer)
+            if dad.is_curr_node_not_read_only_or_error():
+                dad.lists_handler.todo_list_rotate_status(text_iter, text_buffer)
     elif event.button == 3 and not text_buffer.get_has_selection():
         x, y = text_view.window_to_buffer_coords(gtk.TEXT_WINDOW_TEXT, int(event.x), int(event.y))
         text_iter = text_view.get_iter_at_location(x, y)
@@ -118,6 +122,7 @@ def on_sourceview_event_after_button_press(dad, text_view, event):
 
 def on_sourceview_list_change_level(dad, iter_insert, list_info, text_buffer, level_increase):
     """Called at list indent/unindent time"""
+    if not dad.is_curr_node_not_read_only_or_error(): return
     dad.user_active = False
     end_offset = dad.lists_handler.get_multiline_list_element_end_offset(iter_insert, list_info)
     curr_offset = list_info["startoffs"]
@@ -165,7 +170,7 @@ def on_sourceview_list_change_level(dad, iter_insert, list_info, text_buffer, le
             break
         curr_offset = iter_start.get_offset()
     dad.user_active = True
-    dad.state_machine.update_state()
+    dad.update_window_save_needed("nbuf", True)
 
 def on_sourceview_event_after_key_press(dad, text_view, event):
     """Called after every gtk.gdk.KEY_PRESS on the SourceView"""
@@ -245,44 +250,65 @@ def on_sourceview_event_after_key_press(dad, text_view, event):
         elif keyname == cons.STR_KEY_SPACE:
             if iter_start.backward_chars(2):
                 if iter_start.get_char() == cons.CHAR_GREATER and iter_start.backward_char():
-                    # Start bulleted list on "<> ", "-> " and "=> " at line start
                     if iter_start.get_line_offset() == 0:
+                        # at line start
                         if iter_start.get_char() == cons.CHAR_LESSER:
+                            # "<> " becoming "◇ "
                             dad.special_char_replace(cons.CHARS_LISTBUL[1], iter_start, iter_insert, text_buffer)
                         elif iter_start.get_char() == cons.CHAR_MINUS:
+                            # "-> " becoming "→ "
                             dad.special_char_replace(cons.CHARS_LISTBUL[4], iter_start, iter_insert, text_buffer)
                         elif iter_start.get_char() == cons.CHAR_EQUAL:
+                            # "=> " becoming "⇒ "
                             dad.special_char_replace(cons.CHARS_LISTBUL[5], iter_start, iter_insert, text_buffer)
                     elif iter_start.get_char() == cons.CHAR_MINUS and iter_start.backward_char():
                         if iter_start.get_char() == cons.CHAR_LESSER:
+                            # "<-> " becoming "↔ "
                             dad.special_char_replace(cons.SPECIAL_CHAR_ARROW_DOUBLE, iter_start, iter_insert, text_buffer)
                         elif iter_start.get_char() == cons.CHAR_MINUS:
+                            # "--> " becoming "→ "
                             dad.special_char_replace(cons.SPECIAL_CHAR_ARROW_RIGHT, iter_start, iter_insert, text_buffer)
+                    elif iter_start.get_char() == cons.CHAR_EQUAL and iter_start.backward_char():
+                        if iter_start.get_char() == cons.CHAR_LESSER:
+                            # "<=> " becoming "⇔ "
+                            dad.special_char_replace(cons.SPECIAL_CHAR_ARROW_DOUBLE2, iter_start, iter_insert, text_buffer)
+                        elif iter_start.get_char() == cons.CHAR_EQUAL:
+                            # "==> " becoming "⇒ "
+                            dad.special_char_replace(cons.SPECIAL_CHAR_ARROW_RIGHT2, iter_start, iter_insert, text_buffer)
                 elif iter_start.get_char() == cons.CHAR_MINUS and iter_start.backward_char()\
                 and iter_start.get_char() == cons.CHAR_MINUS and iter_start.backward_char()\
                 and iter_start.get_char() == cons.CHAR_LESSER:
+                    # "<-- " becoming "← "
                     dad.special_char_replace(cons.SPECIAL_CHAR_ARROW_LEFT, iter_start, iter_insert, text_buffer)
+                elif iter_start.get_char() == cons.CHAR_EQUAL and iter_start.backward_char()\
+                and iter_start.get_char() == cons.CHAR_EQUAL and iter_start.backward_char()\
+                and iter_start.get_char() == cons.CHAR_LESSER:
+                    # "<== " becoming "⇐ "
+                    dad.special_char_replace(cons.SPECIAL_CHAR_ARROW_LEFT2, iter_start, iter_insert, text_buffer)
                 elif iter_start.get_char() == cons.CHAR_PARENTH_CLOSE and iter_start.backward_char():
                     if iter_start.get_char().lower() == "c" and iter_start.backward_char()\
                     and iter_start.get_char() == cons.CHAR_PARENTH_OPEN:
+                        # "(c) " becoming "© "
                         dad.special_char_replace(cons.SPECIAL_CHAR_COPYRIGHT, iter_start, iter_insert, text_buffer)
                     elif iter_start.get_char().lower() == "r" and iter_start.backward_char()\
                     and iter_start.get_char() == cons.CHAR_PARENTH_OPEN:
+                        # "(r) " becoming "® "
                         dad.special_char_replace(cons.SPECIAL_CHAR_REGISTERED_TRADEMARK, iter_start, iter_insert, text_buffer)
                     elif iter_start.get_char().lower() == "m" and iter_start.backward_char()\
                     and iter_start.get_char() == "t" and iter_start.backward_char()\
                     and iter_start.get_char() == cons.CHAR_PARENTH_OPEN:
+                        # "(tm) " becoming "™ "
                         dad.special_char_replace(cons.SPECIAL_CHAR_UNREGISTERED_TRADEMARK, iter_start, iter_insert, text_buffer)
                 elif iter_start.get_char() == cons.CHAR_STAR and iter_start.get_line_offset() == 0:
-                    # Start bulleted list on "* " at line start
+                    # "* " becoming "• " at line start
                     dad.special_char_replace(cons.CHARS_LISTBUL[0], iter_start, iter_insert, text_buffer)
                 elif iter_start.get_char() == cons.CHAR_SQ_BR_CLOSE and iter_start.backward_char():
-                    # Start todo list on "[] " at line start
                     if iter_start.get_line_offset() == 0 and iter_start.get_char() == cons.CHAR_SQ_BR_OPEN:
+                        # "[] " becoming "☐ " at line start
                         dad.special_char_replace(cons.CHAR_LISTTODO, iter_start, iter_insert, text_buffer)
                 elif iter_start.get_char() == cons.CHAR_COLON and iter_start.backward_char():
-                    # Start todo list on ":: " at line start
                     if iter_start.get_line_offset() == 0 and iter_start.get_char() == cons.CHAR_COLON:
+                        # ":: " becoming "▪ " at line start
                         dad.special_char_replace(cons.CHARS_LISTBUL[2], iter_start, iter_insert, text_buffer)
     return False
 
@@ -424,13 +450,33 @@ def strip_trailing_spaces(text_buffer):
     return cleaned_lines
 
 def get_next_chars_from_iter_are(iter_start, chars_list):
-    """Returns True if the Given Chars are the next 'num' after iter"""
+    """Returns True if one set of the Given Chars are the first after iter"""
     for chars in chars_list:
         text_iter = iter_start.copy()
         num = len(chars)
         for i in range(num):
-            if text_iter.get_char().encode(cons.STR_UTF8) != chars[i]: break
-            if i != num-1 and not text_iter.forward_char(): break
+            if text_iter.get_char().encode(cons.STR_UTF8) != chars[i]:
+                break
+            if i != num-1 and not text_iter.forward_char():
+                break
+        else:
+            return True
+    return False
+
+def get_first_chars_of_string_are(in_string, chars_list):
+    """Returns True if one set of the Given Chars are the first of in_string"""
+    for chars in chars_list:
+        if in_string.startswith(chars):
+            return True
+    return False
+
+def get_first_chars_of_string_at_offset_are(in_string, offset, chars_list):
+    """Returns True if one set of the Given Chars are the first of in_string"""
+    for chars in chars_list:
+        num = len(chars)
+        for i in range(num):
+            if in_string[offset+i] != chars[i]:
+                break
         else: return True
     return False
 
@@ -604,7 +650,7 @@ def dialog_about(dad):
     dialog = gtk.AboutDialog()
     dialog.set_program_name("CherryTree")
     dialog.set_version(cons.VERSION)
-    dialog.set_copyright("""Copyright © 2009-2015
+    dialog.set_copyright("""Copyright © 2009-2016
 Giuseppe Penone <giuspen@gmail.com>""")
     dialog.set_comments(_("A Hierarchical Note Taking Application, featuring Rich Text and Syntax Highlighting"))
     dialog.set_license(_("""
@@ -635,9 +681,11 @@ _("French")+" (fr) Klaus Becker <colonius@free.fr>"+cons.CHAR_NEWLINE+
 _("German")+" (de) Frank Brungräber <calexu@arcor.de>"+cons.CHAR_NEWLINE+
 _("Italian")+" (it) Vincenzo Reale <smart2128@baslug.org>"+cons.CHAR_NEWLINE+
 _("Japanese")+" (ja) Piyo <py2@live.jp>"+cons.CHAR_NEWLINE+
+_("Lithuanian")+" (lt) Zygis <zygimantus@gmail.com>"+cons.CHAR_NEWLINE+
 _("Polish")+" (pl) Marcin Swierczynski <orneo1212@gmail.com>"+cons.CHAR_NEWLINE+
 _("Portuguese Brazil")+" (pt_BR) Vinicius Schmidt <viniciussm@rocketmail.com>"+cons.CHAR_NEWLINE+
 _("Russian")+" (ru) Andriy Kovtun <kovtunos@yandex.ru>"+cons.CHAR_NEWLINE+
+_("Slovenian")+" (sl) Erik Lovrič <erik.lovric@gmail.com>"+cons.CHAR_NEWLINE+
 _("Spanish")+" (es) Daniel MC <i.e.betel@gmail.com>"+cons.CHAR_NEWLINE+
 _("Turkish")+" (tr) Ferhat Aydin <ferhataydin44@gmail.com>"+cons.CHAR_NEWLINE+
 _("Ukrainian")+" (uk) Andriy Kovtun <kovtunos@yandex.ru>")
